#ifndef POKEPLATINUM_UNK_02055C50_H
#define POKEPLATINUM_UNK_02055C50_H

#include "struct_decls/struct_0203CDB0_decl.h"
#include "struct_decls/struct_02055CBC_decl.h"
#include "struct_decls/struct_02061AB4_decl.h"

UnkStruct_02055CBC * sub_02055C8C(UnkStruct_0203CDB0 * param0, int param1);
void sub_02055CBC(UnkStruct_02055CBC * param0);
void sub_02055CD4(UnkStruct_0203CDB0 * param0, int param1);
void sub_02055D94(UnkStruct_0203CDB0 * param0);
BOOL sub_02055E00(UnkStruct_0203CDB0 * param0, UnkStruct_02061AB4 * param1);
void sub_02055E80(UnkStruct_0203CDB0 * param0, UnkStruct_02061AB4 * param1, u16 param2);
void sub_02055EAC(UnkStruct_0203CDB0 * param0, UnkStruct_02061AB4 * param1, u16 param2);
void sub_02055EE0(UnkStruct_0203CDB0 * param0, UnkStruct_02061AB4 * param1);
int sub_02055F00(const UnkStruct_0203CDB0 * param0, const UnkStruct_02061AB4 * param1);
int sub_02055F20(const UnkStruct_0203CDB0 * param0, const UnkStruct_02061AB4 * param1);
u16 sub_02055F40(const UnkStruct_0203CDB0 * param0, const UnkStruct_02061AB4 * param1);
u16 sub_02055F64(const UnkStruct_0203CDB0 * param0, const UnkStruct_02061AB4 * param1);
int sub_02055F88(const UnkStruct_0203CDB0 * param0, const UnkStruct_02061AB4 * param1);
int sub_02055FA8(const UnkStruct_0203CDB0 * param0, const UnkStruct_02061AB4 * param1);
u32 sub_02055FC8(const UnkStruct_0203CDB0 * param0, const UnkStruct_02061AB4 * param1);
void sub_020562AC(UnkStruct_0203CDB0 * param0);
void sub_020562D8(UnkStruct_0203CDB0 * param0);

#endif // POKEPLATINUM_UNK_02055C50_H
